TKind

Enum TKind 

pub enum TKind {
Show 90 variants Comment, OutDoc, InDoc, As, Break, Const, Continue, Do, Else, Enum, False, Fn, For, If, Impl, In, Let, Loop, Macro, Match, Mod, Mut, Pub, Return, Static, Struct, True, Type, Use, While, Identifier, Character, String, Integer, LCurly, RCurly, LBrack, RBrack, LParen, RParen, Amp, AmpAmp, AmpEq, Arrow, At, Backslash, Bang, BangBang, BangEq, Bar, BarBar, BarEq, Colon, ColonColon, Comma, Dollar, Dot, DotDot, DotDotDot, DotDotEq, Eq, EqEq, FatArrow, Grave, Gt, GtEq, GtGt, GtGtEq, Hash, HashBang, Lt, LtEq, LtLt, LtLtEq, Minus, MinusEq, Plus, PlusEq, Question, Rem, RemEq, Semi, Slash, SlashEq, Star, StarEq, Tilde, Xor, XorEq, XorXor,
}
The lexical classification of a Token.

Variants



Comment

Line or block comment



OutDoc

Outer doc comment ///.*



InDoc

Inner doc comment: //!.*



As



Break



Const



Continue



Do



Else



Enum



False



Fn



For



If



Impl



In



Let



Loop



Macro



Match



Mod



Mut



Pub



Return



Static



Struct



True



Type



Use



While



Identifier



Character



String



Integer

0(x[0-9A-Fa-f]* | d[0-9]* | o[0-7]* | b[0-1]*) | [1-9][0-9]*



LCurly

{



RCurly

}



LBrack

[



RBrack

]



LParen

(



RParen

)



Amp

&



AmpAmp

&&



AmpEq

&=



Arrow

->



At

@



Backslash

\



Bang

!



BangBang

!!



BangEq

!=



Bar

|



BarBar

||



BarEq

|=



Colon

:



ColonColon

::



Comma

,



Dollar

$



Dot

.



DotDot

..



DotDotDot



DotDotEq

..=



Eq

=



EqEq

==



FatArrow

=>



Grave

`



Gt



GtEq

=



GtGt



GtGtEq

=



Hash



HashBang

#!



Lt

<



LtEq

<=



LtLt

<<



LtLtEq

<<=



Minus



MinusEq

-=



Plus



PlusEq

+=



Question

?



Rem

%



RemEq

%=



Semi

;



Slash

/



SlashEq

/=



Star



StarEq

*=



Tilde

~



Xor

^



XorEq

^=



XorXor

^^

Implementations

Source

impl TKind

pub const fn flip(self) -> Self

pub const fn split(self) -> Result<(Self, Self), Self>

Splits a single TKind into two, if possible, or returns the original.